@@ -20,7 +20,7 @@
  */
 /*
   File   : canonmn.cpp
-  Version: $Rev: 1473 $
+  Version: $Rev: 1499 $
   Authors: Andreas Huggel (ahu) <ahuggel@gmx.net>
            David Cannings (dc) <david@edeca.net>
   Credits: EXIF MakerNote of Canon by David Burren <http://www.burren.cx/david/canon.html>
@@ -28,7 +28,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: canonmn.cpp 1473 2008-06-03 02:15:04Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: canonmn.cpp 1499 2008-06-10 03:22:59Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -984,8 +984,10 @@ namespace Exiv2 {
     std::ostream& CanonMakerNote::printCsLens(std::ostream& os,
                                                 const Value& value)
     {
-        if (value.typeId() != unsignedShort) return os << value;
-        if (value.count() < 3) return os << value;
+        if (   value.count() < 3
+            || value.typeId() != unsignedShort) {
+            return os << "(" << value << ")";
+        }
 
         float fu = value.toFloat(2);
         if (fu == 0.0) return os << value;
