@@ -20,14 +20,14 @@
  */
 /*
   File:      cr2image.cpp
-  Version:   $Rev: 1366 $
+  Version:   $Rev: 1404 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   22-Apr-06, ahu: created
 
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: cr2image.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: cr2image.cpp 1404 2008-04-15 03:46:01Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -74,9 +74,9 @@ namespace Exiv2 {
         { "*",         0x8649, Group::ifd0,    &TiffMetadataDecoder::decodeIptc }
     };
 
-    const DecoderFct Cr2Decoder::findDecoder(const std::string& make,
-                                                   uint32_t     extendedTag,
-                                                   uint16_t     group)
+    DecoderFct Cr2Decoder::findDecoder(const std::string& make,
+                                             uint32_t     extendedTag,
+                                             uint16_t     group)
     {
         DecoderFct decoderFct = &TiffMetadataDecoder::decodeStdTiffEntry;
         const TiffDecoderInfo* td = find(cr2DecoderInfo_,
@@ -93,6 +93,18 @@ namespace Exiv2 {
     {
     } // Cr2Image::Cr2Image
 
+    int Cr2Image::pixelWidth() const
+    {
+        Exiv2::ExifData::const_iterator widthIter = exifData_.findKey(Exiv2::ExifKey("Exif.Photo.PixelXDimension"));
+        return (widthIter == exifData_.end()) ? 0 : widthIter->toLong();
+    }
+
+    int Cr2Image::pixelHeight() const
+    {
+        Exiv2::ExifData::const_iterator heightIter = exifData_.findKey(Exiv2::ExifKey("Exif.Photo.PixelYDimension"));
+        return (heightIter == exifData_.end()) ? 0 : heightIter->toLong();
+    }
+
     void Cr2Image::setExifData(const ExifData& /*exifData*/)
     {
         // Todo: implement me!
