@@ -21,7 +21,7 @@
 /*!
   @file    cr2image.hpp
   @brief   Class Cr2Image
-  @version $Rev: 1366 $
+  @version $Rev: 1404 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    22-Apr-06, ahu: created
@@ -106,6 +106,8 @@ namespace Exiv2 {
         //! @name Accessors
         //@{
         std::string mimeType() const { return "image/x-canon-cr2"; }
+        int pixelWidth() const;
+        int pixelHeight() const;
         //@}
 
     private:
@@ -137,9 +139,9 @@ namespace Exiv2 {
 
           @return Pointer to the decoder function
          */
-        static const DecoderFct findDecoder(const std::string& make,
-                                                  uint32_t     extendedTag,
-                                                  uint16_t     group);
+        static DecoderFct findDecoder(const std::string& make,
+                                            uint32_t     extendedTag,
+                                            uint16_t     group);
 
     private:
         static const TiffDecoderInfo cr2DecoderInfo_[]; //<! CR2 decoder table
