@@ -23,7 +23,7 @@
   @brief   Class CrwImage to access Canon Crw images.<BR>
            References:<BR>
            <a href="http://www.sno.phy.queensu.ca/~phil/exiftool/canon_raw.html">The Canon RAW (CRW) File Format</a> by Phil Harvey
-  @version $Rev: 1366 $
+  @version $Rev: 1408 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    28-Aug-05, ahu: created
@@ -121,6 +121,8 @@ namespace Exiv2 {
         //! @name Accessors
         //@{
         std::string mimeType() const { return "image/x-canon-crw"; }
+        int pixelWidth() const;
+        int pixelHeight() const;
         //@}
 
     private:
@@ -414,6 +416,7 @@ namespace Exiv2 {
     private:
         //! @name Manipulators
         //@{
+        using CiffComponent::doAdd;
         // See base class comment
         virtual void doAdd(AutoPtr component);
         /*!
