@@ -20,13 +20,13 @@
  */
 /*
   File:      error.cpp
-  Version:   $Rev: 1366 $
+  Version:   $Rev: 1475 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   02-Apr-05, ahu: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: error.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: error.cpp 1475 2008-06-03 02:34:51Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -58,7 +58,7 @@ namespace Exiv2 {
         ErrMsg( 13, N_("Image type %1 is not supported")), // %1=image type
         ErrMsg( 14, N_("Failed to read image data")),
         ErrMsg( 15, N_("This does not look like a JPEG image")),
-        ErrMsg( 16, N_("MakerTagInfo registry full")),
+//        ErrMsg( 16, N_("")), -- currently not used
         ErrMsg( 17, N_("%1: Failed to rename file to %2: %3")), // %1=old path, %2=new path, %3=strerror
         ErrMsg( 18, N_("%1: Transfer failed: %2")), // %1=path, %2=strerror
         ErrMsg( 19, N_("Memory transfer failed: %1")), // %1=strerror
