@@ -20,14 +20,14 @@
  */
 /*
   File:      exif.cpp
-  Version:   $Rev: 1366 $
+  Version:   $Rev: 1402 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   26-Jan-04, ahu: created
              11-Feb-04, ahu: isolated as a component
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: exif.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: exif.cpp 1402 2008-04-04 15:50:11Z ahuggel $")
 
 // Define DEBUG_MAKERNOTE to output debug information to std::cerr, e.g, by
 // calling make like this: make DEFS=-DDEBUG_MAKERNOTE exif.o
@@ -111,6 +111,11 @@ namespace Exiv2 {
         if (rhs.value_.get() != 0) value_ = rhs.value_->clone(); // deep copy
     }
 
+    std::ostream& Exifdatum::write(std::ostream& os) const
+    {
+        return ExifTags::printTag(os, tag(), ifdId(), value());
+    }
+
     const Value& Exifdatum::value() const
     {
         if (value_.get() == 0) throw Error(8);
@@ -954,7 +959,7 @@ namespace Exiv2 {
                                                 + pGpsIfd_->dataSize());
             }
             if (   maxOffset > pIfd1_->offset()
-                || maxOffset > pIfd1_->dataOffset() && pIfd1_->dataOffset() > 0)
+                || (maxOffset > pIfd1_->dataOffset() && pIfd1_->dataOffset() > 0))
                 rc = false;
             /*
                Todo: Removed condition from the above if(). Should be re-added...
@@ -1281,10 +1286,6 @@ namespace Exiv2 {
         makerNote->add(e);
     } // addToMakerNote
 
-    std::ostream& operator<<(std::ostream& os, const Exifdatum& md)
-    {
-        return ExifTags::printTag(os, md.tag(), md.ifdId(), md.value());
-    }
 }                                       // namespace Exiv2
 
 // *****************************************************************************
