@@ -22,13 +22,13 @@
   Abstract:  Command line program to display and manipulate image %Exif data
 
   File:      exiv2.cpp
-  Version:   $Rev: 1366 $
+  Version:   $Rev: 1458 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   10-Dec-03, ahu: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: exiv2.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: exiv2.cpp 1458 2008-05-22 08:38:20Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -147,7 +147,7 @@ int main(int argc, char* const argv[])
     for (Params::Files::const_iterator i = params.files_.begin(); 
          i != params.files_.end(); ++i) {
         if (params.verbose_) {
-            std::cout << _("File") << " " << std::setw(w) << n++ << "/" << s << ": "
+            std::cout << _("File") << " " << std::setw(w) << std::right << n++ << "/" << s << ": "
                       << *i << std::endl;
         }
         int ret = task->run(*i);
@@ -277,13 +277,13 @@ void Params::help(std::ostream& os) const
        << _("             x : XMP packet\n")
        << _("             c : JPEG comment\n")
        << _("   -i tgt  Insert target(s) for the 'insert' action. Possible targets are\n"
-            "           the same as those for the -d option, plus:\n"
-            "             X : Insert XMP packet from <file>.xmp\n"
+            "           the same as those for the -d option, plus a modifier:\n"
+            "             X : Insert metadata from an XMP sidecar file <file>.xmp\n"
             "           Only JPEG thumbnails can be inserted, they need to be named\n"
             "           <file>-thumb.jpg\n")
        << _("   -e tgt  Extract target(s) for the 'extract' action. Possible targets\n"
-            "           are the same as those for the -i option, plus:\n"
-            "             X : Extract XMP packet to <file>.xmp\n")
+            "           are the same as those for the -d option, plus a modifier:\n"
+            "             X : Extract metadata to an XMP sidecar file <file>.xmp\n")
        << _("   -r fmt  Filename format for the 'rename' action. The format string\n"
             "           follows strftime(3). The following keywords are supported:\n")
        << _("             :basename:   - original filename without extension\n")
@@ -840,13 +840,16 @@ namespace {
             case 'e': target |= Params::ctExif; break;
             case 'i': target |= Params::ctIptc; break;
             case 'x': target |= Params::ctXmp; break;
-            case 'X': target |= Params::ctXmpPacket; break;
             case 'c': target |= Params::ctComment; break;
             case 't': target |= Params::ctThumb; break;
             case 'a': target |=   Params::ctExif
                                 | Params::ctIptc
                                 | Params::ctComment
                                 | Params::ctXmp; break;
+            case 'X':
+                target |= Params::ctXmpSidecar;
+                if (optarg == "X") target |= Params::ctExif | Params::ctIptc | Params::ctXmp;
+                break;
             default:
                 std::cerr << Params::instance().progname() << ": " << _("Unrecognized ")
                           << action << " " << _("target") << " `"  << optarg[i] << "'\n";
@@ -1015,6 +1018,12 @@ namespace {
         modifyCmd.explicitType_ = explicitType;
         modifyCmd.value_ = value;
 
+        if (cmdId == reg) {
+            // Registration needs to be done immediately as the new namespaces are
+            // looked up during parsing of subsequent lines (to validate XMP keys).
+            Exiv2::XmpProperties::registerNs(modifyCmd.value_, modifyCmd.key_);
+        }
+
         return true;
     } // parseLine
 
