@@ -21,7 +21,7 @@
 /*!
   @file    exiv2.hpp
   @brief   Defines class Params, used for the command line handling of exiv2
-  @version $Rev: 1366 $
+  @version $Rev: 1457 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    08-Dec-03, ahu: created
@@ -141,7 +141,15 @@ public:
     };
 
     //! Enumerates common targets, bitmap
-    enum CommonTarget { ctExif = 1, ctIptc = 2, ctComment = 4, ctThumb = 8, ctXmp = 16, ctXmpPacket = 32 };
+    enum CommonTarget {
+        ctExif       =  1,
+        ctIptc       =  2,
+        ctComment    =  4,
+        ctThumb      =  8,
+        ctXmp        = 16,
+        ctXmpSidecar = 32
+    };
+
     //! Enumerates the policies to handle existing files in rename action
     enum FileExistsPolicy { overwritePolicy, renamePolicy, askPolicy };
 
