@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2007 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2008 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,14 +20,14 @@
  */
 /*
   File:      utils.cpp
-  Version:   $Rev: 1039 $
+  Version:   $Rev: 1366 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   08-Dec-03, ahu: created
              02-Apr-05, ahu: moved to Exiv2 namespace
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: futils.cpp 1039 2007-02-02 10:09:31Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: futils.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -84,11 +84,11 @@ namespace Exiv2 {
 # ifdef EXV_STRERROR_R_CHAR_P
         char *buf = 0;
         char buf2[n];
-        memset(buf2, 0x0, n);
+        std::memset(buf2, 0x0, n);
         buf = strerror_r(error, buf2, n);
 # else
         char buf[n];
-        memset(buf, 0x0, n);
+        std::memset(buf, 0x0, n);
         strerror_r(error, buf, n);
 # endif
         os << buf;
