@@ -20,7 +20,7 @@
  */
 /*
   File:      image.cpp
-  Version:   $Rev: 1404 $
+  Version:   $Rev: 1507 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
              Brad Schick (brad) <brad@robotbattle.com>
   History:   26-Jan-04, ahu: created
@@ -30,7 +30,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: image.cpp 1404 2008-04-15 03:46:01Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: image.cpp 1507 2008-06-18 14:23:00Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -89,9 +89,9 @@ namespace Exiv2 {
         { ImageType::mrw,  newMrwInstance,  isMrwType,  amRead,      amRead,      amRead,      amNone      },
         { ImageType::tiff, newTiffInstance, isTiffType, amRead,      amRead,      amRead,      amNone      },
         { ImageType::orf,  newOrfInstance,  isOrfType,  amRead,      amRead,      amRead,      amNone      },
-  #ifdef EXV_HAVE_LIBZ
-        { ImageType::png,  newPngInstance,  isPngType,  amRead,      amRead,      amRead,      amNone      },
-  #endif // EXV_HAVE_LIBZ
+#ifdef EXV_HAVE_LIBZ
+        { ImageType::png,  newPngInstance,  isPngType,  amRead,      amRead,      amRead,      amRead      },
+#endif // EXV_HAVE_LIBZ
         { ImageType::raf,  newRafInstance,  isRafType,  amRead,      amRead,      amRead,      amNone      },
         { ImageType::xmp,  newXmpInstance,  isXmpType,  amNone,      amNone,      amReadWrite, amNone      },
         { ImageType::gif,  newGifInstance,  isGifType,  amNone,      amNone,      amNone,      amNone      },
