@@ -21,7 +21,7 @@
 /*!
   @file    iptc.hpp
   @brief   Encoding and decoding of IPTC data
-  @version $Rev: 1366 $
+  @version $Rev: 1391 $
   @author  Brad Schick (brad)
            <a href="mailto:brad@robotbattle.com">brad@robotbattle.com</a>
   @date    31-Jul-04, brad: created
@@ -111,6 +111,7 @@ namespace Exiv2 {
         //@{
         long copy(byte* buf, ByteOrder byteOrder) const
             { return value_.get() == 0 ? 0 : value_->copy(buf, byteOrder); }
+        std::ostream& write(std::ostream& os) const;
         /*!
           @brief Return the key of the Iptcdatum. The key is of the form
                  '<b>Iptc</b>.recordName.datasetName'. Note however that the key
@@ -169,12 +170,6 @@ namespace Exiv2 {
 
     }; // class Iptcdatum
 
-    /*!
-      @brief Output operator for Iptcdatum types, printing the interpreted
-             tag value.
-     */
-    std::ostream& operator<<(std::ostream& os, const Iptcdatum& md);
-
     //! Container type to hold all metadata
     typedef std::vector<Iptcdatum> IptcMetadata;
 
