@@ -20,7 +20,7 @@
  */
 /*
   File:      metadatum.cpp
-  Version:   $Rev: 1366 $
+  Version:   $Rev: 1391 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
              Brad Schick (brad) <brad@robotbattle.com>
   History:   26-Jan-04, ahu: created
@@ -28,7 +28,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: metadatum.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: metadatum.cpp 1391 2008-02-16 18:08:44Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -70,17 +70,11 @@ namespace Exiv2 {
         return *this;
     }
 
-    std::ostream& operator<<(std::ostream& os, const Metadatum& md)
+    std::string Metadatum::print() const
     {
-        os << "0x" << std::setw(4) << std::setfill('0') << std::right
-                  << std::hex << md.tag() << " "
-                  << std::setw(40) << std::setfill(' ') << std::left
-                  << md.key() << " "
-                  << std::setw(9) << std::setfill(' ') << std::left
-                  << md.typeName() << " "
-                  << std::dec << md.value()
-                  << "\n";
-        return os;
+        std::ostringstream os;
+        write(os);
+        return os.str();
     }
 
     bool cmpMetadataByTag(const Metadatum& lhs, const Metadatum& rhs)
