@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2006 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2008 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -24,13 +24,13 @@
            <a href="http://www.dalibor.cz/minolta/makernote.htm">Minolta Makernote Format Specification</a> by Dalibor Jelinek,<br>
            <a href="http://www.sno.phy.queensu.ca/~phil/exiftool/TagNames/Minolta.html">Minolta Makernote list</a> by Phil Harvey<br>
            <a href="http://www.ozhiker.com/electronics/pjmt/jpeg_info/minolta_mn.html">Minolta Makernote list from PHP JPEG Metadata Toolkit</a><br>
-           Email communication with <a href="mailto:caulier dot gilles at kdemail dot net">caulier dot gilles at kdemail dot net</a><br>
+           Email communication with <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a><br>
            Some Minolta camera settings have been decoded by <a href="mailto:xraynaud@gmail.com">Xavier Raynaud</a> from digiKam project and added by Gilles Caulier.
-  @version $Rev: 986 $
+  @version $Rev: 1366 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
-  @author  Gilles Caulier (gc)
-           <a href="mailto:caulier dot gilles at kdemail dot net">caulier dot gilles at kdemail dot net</a>
+  @author  Gilles Caulier (cgilles)
+           <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
   @date    06-May-06, gc: submitted
  */
 #ifndef MINOLTAMN_HPP_
@@ -159,9 +159,9 @@ namespace Exiv2 {
         //! Print Brightness setting from standard Minolta Camera Settings makernote
         static std::ostream& printMinoltaBrightnessStd(std::ostream& os, const Value& value);
 
-	//! Print Exposure Manual Bias setting from 5D Minolta Camera Settings makernote
+        //! Print Exposure Manual Bias setting from 5D Minolta Camera Settings makernote
         static std::ostream& printMinoltaExposureManualBias5D(std::ostream& os, const Value& value);
-	//! Print Exposure Compensation setting from 5D Minolta Camera Settings makernote
+        //! Print Exposure Compensation setting from 5D Minolta Camera Settings makernote
         static std::ostream& printMinoltaExposureCompensation5D(std::ostream& os, const Value& value);
         //@}
 
