@@ -20,14 +20,14 @@
  */
 /*
   File:      mrwimage.cpp
-  Version:   $Rev: 1366 $
+  Version:   $Rev: 1404 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   13-May-06, ahu: created
   Credits:   See header file
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: mrwimage.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: mrwimage.cpp 1404 2008-04-15 03:46:01Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -59,6 +59,26 @@ namespace Exiv2 {
     {
     } // MrwImage::MrwImage
 
+    int MrwImage::pixelWidth() const
+    {
+        ExifData::const_iterator imageWidth;
+        if ((imageWidth = exifData_.findKey(Exiv2::ExifKey("Exif.Image.ImageWidth"))) != exifData_.end())
+        {
+            return imageWidth->toLong();
+        }
+        return 0;
+    }
+
+    int MrwImage::pixelHeight() const
+    {
+        ExifData::const_iterator imageHeight;
+        if ((imageHeight = exifData_.findKey(Exiv2::ExifKey("Exif.Image.ImageLength"))) != exifData_.end())
+        {
+            return imageHeight->toLong();
+        }
+        return 0;
+    }
+
     void MrwImage::setExifData(const ExifData& /*exifData*/)
     {
         // Todo: implement me!
