@@ -23,7 +23,7 @@
  */
 /*
   File:      nikonmn.cpp
-  Version:   $Rev: 1473 $
+  Version:   $Rev: 1499 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
              Gilles Caulier (gc) <caulier.gilles@kdemail.net>
   History:   17-May-04, ahu: created
@@ -31,7 +31,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: nikonmn.cpp 1473 2008-06-03 02:15:04Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: nikonmn.cpp 1499 2008-06-10 03:22:59Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -1067,7 +1067,10 @@ namespace Exiv2 {
                                                const Value& value)
     {
         // Decoded by Robert Rottmerhusen <email@rottmerhusen.com>
-        if (value.size() != 4) return os << "(" << value << ")";
+        if (   value.size() != 4
+            || value.typeId() != undefined) {
+            return os << "(" << value << ")";
+        }
         float a = value.toFloat(0);
         long  b = value.toLong(1);
         long  c = value.toLong(2);
