@@ -20,7 +20,7 @@
  */
 /*
   File:      olympusmn.cpp
-  Version:   $Rev: 1473 $
+  Version:   $Rev: 1499 $
   Author(s): Will Stokes (wuz) <wstokes@gmail.com>
              Andreas Huggel (ahu) <ahuggel@gmx.net>
              Gilles Caulier (gc) <caulier.gilles@kdemail.net>
@@ -30,7 +30,7 @@
 
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: olympusmn.cpp 1473 2008-06-03 02:15:04Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: olympusmn.cpp 1499 2008-06-10 03:22:59Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -506,6 +506,10 @@ namespace Exiv2 {
 
     std::ostream& OlympusMakerNote::print0x0204(std::ostream& os, const Value& value)
     {
+        if (   value.count() == 0
+            || value.toRational().second == 0) {
+            return os << "(" << value << ")";
+        }
         float f = value.toFloat();
         if (f == 0.0 || f == 1.0) return os << _("None");
         std::ostringstream oss;
