@@ -20,7 +20,7 @@
  */
 /*
   File:      sigmamn.cpp
-  Version:   $Rev: 1366 $
+  Version:   $Rev: 1473 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   02-Apr-04, ahu: created
   Credits:   Sigma and Foveon MakerNote implemented according to the specification
@@ -29,7 +29,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: sigmamn.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: sigmamn.cpp 1473 2008-06-03 02:15:04Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -57,8 +57,6 @@ namespace Exiv2 {
         MakerNoteFactory::registerMakerNote("FOVEON", "*", createSigmaMakerNote);
         MakerNoteFactory::registerMakerNote(
             sigmaIfdId, MakerNote::AutoPtr(new SigmaMakerNote));
-
-        ExifTags::registerMakerTagInfo(sigmaIfdId, tagInfo_);
     }
     //! @endcond
 
@@ -178,10 +176,10 @@ namespace Exiv2 {
         int rc = 0;
         // Check the SIGMA or FOVEON prefix
         if (   header_.size_ < 10
-            || std::string(reinterpret_cast<char*>(header_.pData_), 8)
+            || (   std::string(reinterpret_cast<char*>(header_.pData_), 8)
                         != std::string("SIGMA\0\0\0", 8)
-            && std::string(reinterpret_cast<char*>(header_.pData_), 8)
-                        != std::string("FOVEON\0\0", 8)) {
+                && std::string(reinterpret_cast<char*>(header_.pData_), 8)
+                        != std::string("FOVEON\0\0", 8))) {
             rc = 2;
         }
         return rc;
