@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2006-2007 Andreas Huggel <ahuggel@gmx.net>
+ * Copyright (C) 2004-2008 Andreas Huggel <ahuggel@gmx.net>
  *
  * This program is part of the Exiv2 distribution.
  *
@@ -20,13 +20,13 @@
  */
 /*
   File:      tiffvisitor.cpp
-  Version:   $Rev: 1040 $
+  Version:   $Rev: 1366 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   11-Apr-06, ahu: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: tiffvisitor.cpp 1040 2007-02-02 10:11:43Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: tiffvisitor.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -207,6 +207,33 @@ namespace Exiv2 {
         }
     }
 
+    void TiffMetadataDecoder::decodeXmp(const TiffEntryBase* object)
+    {
+        // add Exif tag anyway
+        decodeStdTiffEntry(object);
+
+        byte const* pData = 0;
+        long size = 0;
+        getObjData(pData, size, 0x02bc, Group::ifd0, object);
+        if (pData) {
+            std::string& xmpPacket = pImage_->xmpPacket();
+            xmpPacket.assign(reinterpret_cast<const char*>(pData), size);
+            std::string::size_type idx = xmpPacket.find_first_of('<');
+            if (idx != std::string::npos && idx > 0) {
+#ifndef SUPPRESS_WARNINGS
+                std::cerr << "Warning: Removing " << static_cast<unsigned long>(idx)
+						  << " characters from the beginning of the XMP packet\n";
+#endif
+                xmpPacket = xmpPacket.substr(idx);
+            }
+            if (XmpParser::decode(pImage_->xmpData(), xmpPacket)) {
+#ifndef SUPPRESS_WARNINGS
+                std::cerr << "Warning: Failed to decode XMP metadata.\n";
+#endif
+            }
+        }
+    } // TiffMetadataDecoder::decodeXmp
+
     void TiffMetadataDecoder::decodeIptc(const TiffEntryBase* object)
     {
         // add Exif tag anyway
