@@ -20,7 +20,7 @@
  */
 /*
   File:      value.cpp
-  Version:   $Rev: 1366 $
+  Version:   $Rev: 1421 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   26-Jan-04, ahu: created
              11-Feb-04, ahu: isolated as a component
@@ -28,7 +28,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: value.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: value.cpp 1421 2008-05-01 08:22:26Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -568,17 +568,17 @@ namespace Exiv2 {
 
     long XmpTextValue::toLong(long /*n*/) const
     {
-        return stringTo<long>(value_, ok_);
+        return parseLong(value_, ok_);
     }
 
     float XmpTextValue::toFloat(long /*n*/) const
     {
-        return stringTo<float>(value_, ok_);
+        return parseFloat(value_, ok_);
     }
 
     Rational XmpTextValue::toRational(long /*n*/) const
     {
-        return stringTo<Rational>(value_, ok_);
+        return parseRational(value_, ok_);
     }
 
     XmpTextValue* XmpTextValue::clone_() const
@@ -626,17 +626,17 @@ namespace Exiv2 {
 
     long XmpArrayValue::toLong(long n) const
     {
-        return stringTo<long>(value_[n], ok_);
+        return parseLong(value_[n], ok_);
     }
 
     float XmpArrayValue::toFloat(long n) const
     {
-        return stringTo<float>(value_[n], ok_);
+        return parseFloat(value_[n], ok_);
     }
 
     Rational XmpArrayValue::toRational(long n) const
     {
-        return stringTo<Rational>(value_[n], ok_);
+        return parseRational(value_[n], ok_);
     }
 
     XmpArrayValue* XmpArrayValue::clone_() const
@@ -702,6 +702,16 @@ namespace Exiv2 {
 
     std::string LangAltValue::toString(long /*n*/) const 
     {
+        return toString("x-default");
+    }
+
+    std::string LangAltValue::toString(const std::string& qualifier) const 
+    {
+        ValueType::const_iterator i = value_.find(qualifier);
+        if (i != value_.end()) {
+            ok_ = true;
+            return i->second;
+        }
         ok_ = false;
         return "";
     }
