@@ -20,13 +20,13 @@
  */
 /*
   File:      xmp.cpp
-  Version:   $Rev: 1484 $
+  Version:   $Rev: 1508 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   13-July-07, ahu: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: xmp.cpp 1484 2008-06-04 08:38:14Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: xmp.cpp 1508 2008-06-18 15:37:56Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -576,7 +576,10 @@ namespace Exiv2 {
                                 uint16_t     formatFlags,
                                 uint32_t     padding)
     { try {
-        if (xmpData.empty()) return 0;
+        if (xmpData.empty()) {
+            xmpPacket.clear();
+            return 0;
+        }
 
         if (!initialize()) {
 #ifndef SUPPRESS_WARNINGS
